@@ -14,7 +14,7 @@ use vars qw( @EXPORT_OK %EXPORT_TAGS );
 %EXPORT_TAGS = ( 'all' => \@EXPORT_OK );
 
 use vars '$VERSION';
-$VERSION = '1.25';
+$VERSION = '1.27';
 my $CPERL = $^V =~ /c$/ ? 1 : 0;
 
 use vars '@Scalars';
@@ -488,6 +488,10 @@ use vars '@Barewords';
      method
     ) : ()
   ),
+  ($] >= 5.039002 ? qw{
+     __CLASS__
+    } : ()
+  ),
 );
 
 # Extra barewords not in keywords.h (import was never in keywords)
